bo4e.enum package
=================

Submodules
----------

bo4e.enum.angebotsstatus module
-------------------------------

.. automodule:: bo4e.enum.angebotsstatus
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.anrede module
-----------------------

.. automodule:: bo4e.enum.anrede
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.arithmetische\_operation module
-----------------------------------------

.. automodule:: bo4e.enum.arithmetische_operation
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.artikelid module
--------------------------

.. automodule:: bo4e.enum.artikelid
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.aufabschlagstyp module
--------------------------------

.. automodule:: bo4e.enum.aufabschlagstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.aufabschlagsziel module
---------------------------------

.. automodule:: bo4e.enum.aufabschlagsziel
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.ausschreibungsportal module
-------------------------------------

.. automodule:: bo4e.enum.ausschreibungsportal
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.ausschreibungsstatus module
-------------------------------------

.. automodule:: bo4e.enum.ausschreibungsstatus
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.ausschreibungstyp module
----------------------------------

.. automodule:: bo4e.enum.ausschreibungstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.bdewartikelnummer module
----------------------------------

.. automodule:: bo4e.enum.bdewartikelnummer
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.bemessungsgroesse module
----------------------------------

.. automodule:: bo4e.enum.bemessungsgroesse
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.bilanzierungsmethode module
-------------------------------------

.. automodule:: bo4e.enum.bilanzierungsmethode
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.botyp module
----------------------

.. automodule:: bo4e.enum.botyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.dienstleistungstyp module
-----------------------------------

.. automodule:: bo4e.enum.dienstleistungstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.energierichtung module
--------------------------------

.. automodule:: bo4e.enum.energierichtung
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.erzeugungsart module
------------------------------

.. automodule:: bo4e.enum.erzeugungsart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.gasqualitaet module
-----------------------------

.. automodule:: bo4e.enum.gasqualitaet
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.gebiettyp module
--------------------------

.. automodule:: bo4e.enum.gebiettyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.geraetemerkmal module
-------------------------------

.. automodule:: bo4e.enum.geraetemerkmal
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.geraetetyp module
---------------------------

.. automodule:: bo4e.enum.geraetetyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.geschaeftspartnerrolle module
---------------------------------------

.. automodule:: bo4e.enum.geschaeftspartnerrolle
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.gueltigkeitstyp module
--------------------------------

.. automodule:: bo4e.enum.gueltigkeitstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.kalkulationsmethode module
------------------------------------

.. automodule:: bo4e.enum.kalkulationsmethode
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.kontaktart module
---------------------------

.. automodule:: bo4e.enum.kontaktart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.kostenklasse module
-----------------------------

.. automodule:: bo4e.enum.kostenklasse
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.kundengruppe module
-----------------------------

.. automodule:: bo4e.enum.kundengruppe
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.kundengruppeka module
-------------------------------

.. automodule:: bo4e.enum.kundengruppeka
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.kundentyp module
--------------------------

.. automodule:: bo4e.enum.kundentyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.landescode module
---------------------------

.. automodule:: bo4e.enum.landescode
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.leistungstyp module
-----------------------------

.. automodule:: bo4e.enum.leistungstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.lokationstyp module
-----------------------------

.. automodule:: bo4e.enum.lokationstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.marktrolle module
---------------------------

.. automodule:: bo4e.enum.marktrolle
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.medium module
-----------------------

.. automodule:: bo4e.enum.medium
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.mengeneinheit module
------------------------------

.. automodule:: bo4e.enum.mengeneinheit
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.mengenoperator module
-------------------------------

.. automodule:: bo4e.enum.mengenoperator
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.messart module
------------------------

.. automodule:: bo4e.enum.messart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.messgroesse module
----------------------------

.. automodule:: bo4e.enum.messgroesse
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.messpreistyp module
-----------------------------

.. automodule:: bo4e.enum.messpreistyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.messwertstatus module
-------------------------------

.. automodule:: bo4e.enum.messwertstatus
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.messwertstatuszusatz module
-------------------------------------

.. automodule:: bo4e.enum.messwertstatuszusatz
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.netzebene module
--------------------------

.. automodule:: bo4e.enum.netzebene
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.nnrechnungsart module
-------------------------------

.. automodule:: bo4e.enum.nnrechnungsart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.nnrechnungstyp module
-------------------------------

.. automodule:: bo4e.enum.nnrechnungstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.oekolabel module
--------------------------

.. automodule:: bo4e.enum.oekolabel
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.oekozertifikat module
-------------------------------

.. automodule:: bo4e.enum.oekozertifikat
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.preisgarantietyp module
---------------------------------

.. automodule:: bo4e.enum.preisgarantietyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.preismodell module
----------------------------

.. automodule:: bo4e.enum.preismodell
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.preisstatus module
----------------------------

.. automodule:: bo4e.enum.preisstatus
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.preistyp module
-------------------------

.. automodule:: bo4e.enum.preistyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.rechnungslegung module
--------------------------------

.. automodule:: bo4e.enum.rechnungslegung
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.rechnungsstatus module
--------------------------------

.. automodule:: bo4e.enum.rechnungsstatus
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.rechnungstyp module
-----------------------------

.. automodule:: bo4e.enum.rechnungstyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.regionskriteriumtyp module
------------------------------------

.. automodule:: bo4e.enum.regionskriteriumtyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.rollencodetyp module
------------------------------

.. automodule:: bo4e.enum.rollencodetyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.rufnummernart module
------------------------------

.. automodule:: bo4e.enum.rufnummernart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.sparte module
-----------------------

.. automodule:: bo4e.enum.sparte
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.steuerkennzeichen module
----------------------------------

.. automodule:: bo4e.enum.steuerkennzeichen
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.strenum module
------------------------

.. automodule:: bo4e.enum.strenum
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.tarifart module
-------------------------

.. automodule:: bo4e.enum.tarifart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.tarifkalkulationsmethode module
-----------------------------------------

.. automodule:: bo4e.enum.tarifkalkulationsmethode
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.tarifmerkmal module
-----------------------------

.. automodule:: bo4e.enum.tarifmerkmal
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.tarifregionskriterium module
--------------------------------------

.. automodule:: bo4e.enum.tarifregionskriterium
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.tariftyp module
-------------------------

.. automodule:: bo4e.enum.tariftyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.tarifzeit module
--------------------------

.. automodule:: bo4e.enum.tarifzeit
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.themengebiet module
-----------------------------

.. automodule:: bo4e.enum.themengebiet
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.titel module
----------------------

.. automodule:: bo4e.enum.titel
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.verbrauchsart module
------------------------------

.. automodule:: bo4e.enum.verbrauchsart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.vertragsart module
----------------------------

.. automodule:: bo4e.enum.vertragsart
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.vertragsform module
-----------------------------

.. automodule:: bo4e.enum.vertragsform
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.vertragsstatus module
-------------------------------

.. automodule:: bo4e.enum.vertragsstatus
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.voraussetzungen module
--------------------------------

.. automodule:: bo4e.enum.voraussetzungen
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.waehrungscode module
------------------------------

.. automodule:: bo4e.enum.waehrungscode
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.waehrungseinheit module
---------------------------------

.. automodule:: bo4e.enum.waehrungseinheit
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.wertermittlungsverfahren module
-----------------------------------------

.. automodule:: bo4e.enum.wertermittlungsverfahren
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.zaehlerauspraegung module
-----------------------------------

.. automodule:: bo4e.enum.zaehlerauspraegung
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.zaehlertyp module
---------------------------

.. automodule:: bo4e.enum.zaehlertyp
   :members:
   :undoc-members:
   :show-inheritance:

bo4e.enum.zeiteinheit module
----------------------------

.. automodule:: bo4e.enum.zeiteinheit
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bo4e.enum
   :members:
   :undoc-members:
   :show-inheritance:
